@@ -9,6 +9,7 @@
 #include "settings/settingspagebase.h"
 
 class QCheckBox;
+class QRadioButton;
 
 /**
  * @brief Page for the 'Navigation' settings of the Dolphin settings dialog.
@@ -33,6 +34,8 @@ private:
 private:
     QCheckBox* m_openArchivesAsFolder;
     QCheckBox* m_autoExpandFolders;
+    QRadioButton* m_openNewTabAfterLastTab;
+    QRadioButton* m_openNewTabAfterCurrentTab;
 };
 
 #endif
